/*==================================================================
  ==================================================================
  ==	XMusic -- An Interactive Interface to Csound		  ==
  ==       Copyright (C) 1988 by George D. Drapeau                ==
  ==                  All Rights Reserved                         ==
  ==================================================================
  ==================================================================
*/
/* $Log:	toolPalette.c,v $
 * Revision 1.2  89/08/06  18:15:00  drapeau
 * Changed calls from XCreatePixmapFromBitmapData to
 * XCreateBitmapFromData.
 * Also, eliminated several extraneous variables and
 * function calls.
 *  */

#include <stdio.h>
#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Shell.h>
#include <X11/Xaw/Box.h>
#include <X11/Xaw/Command.h>
#define USEBITMAPS
#include "defs.h"
#include "externs.h"


Widget	sineCommand,envCommand,sumCommand,ampCommand;		    /* Widgets used by all functions in this file */
Widget	paramCommand,noiseCommand,eqCommand;
Widget	boxWidget;

void CreateToolPalette()					    /* This function is responsible for creating the... */
{								    /* ...palette of Command buttons used by XMusic.  */
  toolPalette	= XtCreatePopupShell("toolPalette",		    /* Create a Popup shell for the Tool Palette */
				     topLevelShellWidgetClass,
				     topLevelShell,
				     NULL,NULL);

  boxWidget	= XtCreateManagedWidget("tools",		    /* Create a box to hold several Command widgets */
					boxWidgetClass,		    /* This is a Box Widget */
					toolPalette,		    /* This widget is a child of Tool Palette Popup shell */
					NULL,NULL);
  sineCommand	= XtCreateManagedWidget("sineTool",		    /* Create the command button widgets */
					commandWidgetClass,
					boxWidget,
					NULL,NULL);
  envCommand	= XtCreateManagedWidget("envTool",		    
					commandWidgetClass,
					boxWidget,
					NULL,NULL);
  sumCommand	= XtCreateManagedWidget("sumTool",		   
					commandWidgetClass,
					boxWidget,
					NULL,NULL);
  ampCommand	= XtCreateManagedWidget("ampTool",		  
					commandWidgetClass,
					boxWidget,
					NULL,NULL);
  paramCommand	= XtCreateManagedWidget("paramTool",		  
					commandWidgetClass,
					boxWidget,
					NULL,NULL);
  eqCommand	= XtCreateManagedWidget("eqTool",		  
					commandWidgetClass,
					boxWidget,
					NULL,NULL);
  noiseCommand	= XtCreateManagedWidget("noiseTool",		  
					commandWidgetClass,
					boxWidget,
					NULL,NULL);
  XtAddCallback(sineCommand,XtNcallback,SineCallback,NULL);	    /* Add callbacks for the tools in the palette */
  XtAddCallback(envCommand,XtNcallback,EnvCallback,NULL);
  XtAddCallback(sumCommand,XtNcallback,SumCallback,NULL);
  XtAddCallback(ampCommand,XtNcallback,AmpCallback,NULL);
  XtAddCallback(paramCommand,XtNcallback,ParamCallback,NULL);
  XtAddCallback(eqCommand,XtNcallback,EQCallback,NULL);
  XtAddCallback(noiseCommand,XtNcallback,NoiseCallback,NULL);
}								    /* end function CreateToolPalette */



void CreateToolPixmaps()
{
  Arg			argList[1];
  Window		xmusicWin;

  xmusicWin = XtWindow(topLevelShell);				    /* ...later use in creating Pixmaps */
  
  sineMap	= XCreateBitmapFromData(dpy,xmusicWin,	    /* Create pixmaps for tools in the palette */
					sine64_bits,sine64_width,sine64_height);
  envMap	= XCreateBitmapFromData(dpy,xmusicWin,
					env64_bits,env64_width,env64_height);
  sumMap	= XCreateBitmapFromData(dpy,xmusicWin,
					sum64_bits,sum64_width,sum64_height);
  ampMap	= XCreateBitmapFromData(dpy,xmusicWin,
					amp64_bits,amp64_width,amp64_height);
  paramMap	= XCreateBitmapFromData(dpy,xmusicWin,
					param64_bits,param64_width,param64_height);
  eqMap		= XCreateBitmapFromData(dpy,xmusicWin,
					eq64_bits,eq64_width,eq64_height);
  noiseMap	= XCreateBitmapFromData(dpy,xmusicWin,
					noise64_bits,noise64_width,noise64_height);

  XtSetArg(argList[0],XtNbitmap,sineMap);			    /* Use bitmaps for the Command widgets instead of labels */
  XtSetValues(sineCommand,argList,XtNumber(argList));		    /* Change the Command widgets with the values just set. */

  XtSetArg(argList[0],XtNbitmap,envMap);
  XtSetValues(envCommand,argList,XtNumber(argList));

  XtSetArg(argList[0],XtNbitmap,sumMap);
  XtSetValues(sumCommand,argList,XtNumber(argList));

  XtSetArg(argList[0],XtNbitmap,ampMap);
  XtSetValues(ampCommand,argList,XtNumber(argList));

  XtSetArg(argList[0],XtNbitmap,paramMap);
  XtSetValues(paramCommand,argList,XtNumber(argList));

  XtSetArg(argList[0],XtNbitmap,eqMap);
  XtSetValues(eqCommand,argList,XtNumber(argList));

  XtSetArg(argList[0],XtNbitmap,noiseMap);
  XtSetValues(noiseCommand,argList,XtNumber(argList));
}								    /* end function CreateToolPixmaps */
